Class: Dse::Graph::Path
- Inherits:
-
Object
- Object
- Dse::Graph::Path
- Defined in:
- lib/dse/graph/path.rb
Overview
Path represents a path connecting a set of vertices.
Instance Attribute Summary collapse
-
#labels ⇒ Array<Array>
readonly
Labels in the path.
-
#objects ⇒ Array<Vertex, Edge, Result>
readonly
Objects in the path, coerced to domain objects that we recognize, or a Result otherwise.